@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '1.019000';
+$MetaCPAN::Client::VERSION = '1.020000';
 use Moo;
 use Carp;
 
@@ -81,10 +81,15 @@ sub file {
 }
 
 sub pod {
-    my $self = shift;
-    my $name = shift;
+    my $self   = shift;
+    my $name   = shift;
+    my $params = shift || {};
 
-    return MetaCPAN::Client::Pod->new({ name => $name });
+    return MetaCPAN::Client::Pod->new({
+        request => $self->request,
+        name    => $name,
+        %$params
+    });
 }
 
 sub favorite {
@@ -356,7 +361,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 1.019000
+version 1.020000
 
 =head1 SYNOPSIS
 
@@ -521,6 +526,7 @@ returns a L<MetaCPAN::Client::Pod> object, which supports various output
 formats (html, plain, x_pod & x_markdown).
 
     my $pod = $mcpan->pod('Moo')->html;
+    my $pod = $mcpan->pod('Moo', { url_prefix => $prefix })->html;
 
 =head2 all
 
