@@ -2,11 +2,25 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Pod;
 # ABSTRACT: A Pod object
-$MetaCPAN::Client::Pod::VERSION = '1.019000';
+$MetaCPAN::Client::Pod::VERSION = '1.020000';
 use Moo;
+use Carp;
+
+has request => (
+    is       => 'ro',
+    handles  => [qw<ua fetch post ssearch>],
+    required => 1,
+);
 
 has name => ( is => 'ro', required => 1 );
 
+has url_prefix => (
+    is  => 'ro',
+    isa => sub {
+        ref($_[0]) and croak "url_prefix must be a scalar";
+    }
+);
+
 my @known_formats = qw<
     html plain x_pod x_markdown
 >;
@@ -23,19 +37,14 @@ foreach my $format (@known_formats) {
 }
 
 sub _request {
-    my $self   = shift;
-    my $ctype  = shift || "plain";
-
+    my $self  = shift;
+    my $ctype = shift || "plain";
     $ctype =~ s/_/-/;
 
-    my $name = $self->name;
+    my $url = 'pod/' . $self->name . '?content-type=text/' . $ctype;
+    $self->url_prefix and $url .= '&url_prefix=' . $self->url_prefix;
 
-    require MetaCPAN::Client::Request;
-
-    return
-        MetaCPAN::Client::Request->new->fetch(
-            "pod/${name}?content-type=text/${ctype}"
-        );
+    return $self->request->fetch($url);
 }
 
 
@@ -53,26 +62,34 @@ MetaCPAN::Client::Pod - A Pod object
 
 =head1 VERSION
 
-version 1.019000
+version 1.020000
 
 =head1 SYNOPSIS
 
   use strict;
   use warnings;
   use MetaCPAN::Client;
-  
+
   my $pod = MetaCPAN::Client->new->pod('Moo');
-  
+
   print $pod->html;
 
 =head1 DESCRIPTION
 
 =head1 ATTRIBUTES
 
+=head2 request
+
+A L<MetaCPAN::Client::Request> object (created in L<MetaCPAN::Client>)
+
 =head2 name
 
 The name of the module (probably always the value passed to the pod() method)
 
+=head2 url_prefix
+
+Prefix to be passed through the url_prefix query parameter to the 'pod' endpoint
+
 =head2 x_pod
 
 The raw pod extracted from the file.
